miml.classifier package
=======================

.. automodule:: miml.classifier
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   miml.classifier.mi
   miml.classifier.mimlTOmi
   miml.classifier.mimlTOml

Submodules
----------

.. toctree::
   :maxdepth: 4

   miml.classifier.miml_classifier
